==> tensorforce-0.3.2.tar.gz: tensorforce-0.3.2/tensorforce/core/optimizers/meta_optimizer.py <==
# Copyright 2017 reinforce.io. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

from __future__ import absolute_import
from __future__ import print_function
from __future__ import division

from tensorforce.core.optimizers import Optimizer


class MetaOptimizer(Optimizer):
    """
    A meta optimizer takes the optimization implemented by another optimizer and  
    modifies/optimizes its proposed result. For example, line search might be applied to find a  
    more optimal step size.
    """

    def __init__(self, optimizer):
        """
        Creates a new meta optimizer instance.

        Args:
            optimizer: The optimizer which is modified by this meta optimizer.
        """
        super(MetaOptimizer, self).__init__()
        self.optimizer = Optimizer.from_spec(spec=optimizer)

    def get_variables(self):
        return super(MetaOptimizer, self).get_variables() + self.optimizer.get_variables()

==> tensorforce-0.3.4.tar.gz: tensorforce-0.3.4/tensorforce/core/optimizers/meta_optimizer.py <==
# Copyright 2017 reinforce.io. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

from __future__ import absolute_import
from __future__ import print_function
from __future__ import division

from tensorforce.core.optimizers import Optimizer


class MetaOptimizer(Optimizer):
    """
    A meta optimizer takes the optimization implemented by another optimizer and  
    modifies/optimizes its proposed result. For example, line search might be applied to find a  
    more optimal step size.
    """

    def __init__(self, optimizer, **kwargs):
        """
        Creates a new meta optimizer instance.

        Args:
            optimizer: The optimizer which is modified by this meta optimizer.
        """
        super(MetaOptimizer, self).__init__(**kwargs)

        self.optimizer = Optimizer.from_spec(spec=optimizer, kwargs=kwargs)

    def get_variables(self):
        return super(MetaOptimizer, self).get_variables() + self.optimizer.get_variables()
